package javax.swing.plaf.basic;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.LayoutManager;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseAdapter;
import java.awt.Color;
import java.awt.Graphics;
import java.beans.PropertyChangeEvent;
import java.awt.Dimension;
import java.awt.Insets;
import javax.swing.UIManager;
import java.awt.Cursor;
import sun.swing.DefaultLookup;
import javax.swing.border.Border;
import javax.swing.JButton;
import javax.swing.JSplitPane;
import java.awt.Component;
import java.beans.PropertyChangeListener;
import java.awt.Container;

public class BasicSplitPaneDivider extends Container implements PropertyChangeListener
{
    protected static final int ONE_TOUCH_SIZE = 6;
    protected static final int ONE_TOUCH_OFFSET = 2;
    protected BasicSplitPaneDivider.DragController dragger;
    protected BasicSplitPaneUI splitPaneUI;
    protected int dividerSize;
    protected Component hiddenDivider;
    protected JSplitPane splitPane;
    protected BasicSplitPaneDivider.MouseHandler mouseHandler;
    protected int orientation;
    protected JButton leftButton;
    protected JButton rightButton;
    private Border border;
    private boolean mouseOver;
    private int oneTouchSize;
    private int oneTouchOffset;
    private boolean centerOneTouchButtons;
    
    public BasicSplitPaneDivider(BasicSplitPaneUI basicSplitPaneUI) {
        this.dividerSize = 0;
        this.oneTouchSize = DefaultLookup.getInt(basicSplitPaneUI.getSplitPane(), basicSplitPaneUI, "SplitPane.oneTouchButtonSize", 6);
        this.oneTouchOffset = DefaultLookup.getInt(basicSplitPaneUI.getSplitPane(), basicSplitPaneUI, "SplitPane.oneTouchButtonOffset", 2);
        this.centerOneTouchButtons = DefaultLookup.getBoolean(basicSplitPaneUI.getSplitPane(), basicSplitPaneUI, "SplitPane.centerOneTouchButtons", true);
        this.setLayout(new BasicSplitPaneDivider.DividerLayout());
        this.setBasicSplitPaneUI(basicSplitPaneUI);
        this.orientation = this.splitPane.getOrientation();
        this.setCursor((this.orientation == 1) ? Cursor.getPredefinedCursor(11) : Cursor.getPredefinedCursor(9));
        this.setBackground(UIManager.getColor("SplitPane.background"));
    }
    
    private void revalidateSplitPane() {
        this.invalidate();
        if (this.splitPane != null) {
            this.splitPane.revalidate();
        }
    }
    
    public void setBasicSplitPaneUI(BasicSplitPaneUI splitPaneUI) {
        if (this.splitPane != null) {
            this.splitPane.removePropertyChangeListener(this);
            if (this.mouseHandler != null) {
                this.splitPane.removeMouseListener(this.mouseHandler);
                this.splitPane.removeMouseMotionListener(this.mouseHandler);
                this.removeMouseListener(this.mouseHandler);
                this.removeMouseMotionListener(this.mouseHandler);
                this.mouseHandler = null;
            }
        }
        if ((this.splitPaneUI = splitPaneUI) != null) {
            this.splitPane = splitPaneUI.getSplitPane();
            if (this.splitPane != null) {
                if (this.mouseHandler == null) {
                    this.mouseHandler = new BasicSplitPaneDivider.MouseHandler();
                }
                this.splitPane.addMouseListener(this.mouseHandler);
                this.splitPane.addMouseMotionListener(this.mouseHandler);
                this.addMouseListener(this.mouseHandler);
                this.addMouseMotionListener(this.mouseHandler);
                this.splitPane.addPropertyChangeListener(this);
                if (this.splitPane.isOneTouchExpandable()) {
                    this.oneTouchExpandableChanged();
                }
            }
        }
        else {
            this.splitPane = null;
        }
    }
    
    public BasicSplitPaneUI getBasicSplitPaneUI() {
        return this.splitPaneUI;
    }
    
    public void setDividerSize(int dividerSize) {
        this.dividerSize = dividerSize;
    }
    
    public int getDividerSize() {
        return this.dividerSize;
    }
    
    public void setBorder(Border border) {
        Border border2 = this.border;
        this.border = border;
    }
    
    public Border getBorder() {
        return this.border;
    }
    
    @Override
    public Insets getInsets() {
        Border border = this.getBorder();
        if (border != null) {
            return border.getBorderInsets(this);
        }
        return super.getInsets();
    }
    
    protected void setMouseOver(boolean mouseOver) {
        this.mouseOver = mouseOver;
    }
    
    public boolean isMouseOver() {
        return this.mouseOver;
    }
    
    @Override
    public Dimension getPreferredSize() {
        if (this.orientation == 1) {
            return new Dimension(this.getDividerSize(), 1);
        }
        return new Dimension(1, this.getDividerSize());
    }
    
    @Override
    public Dimension getMinimumSize() {
        return this.getPreferredSize();
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        if (propertyChangeEvent.getSource() == this.splitPane) {
            if (propertyChangeEvent.getPropertyName() == "orientation") {
                this.orientation = this.splitPane.getOrientation();
                this.setCursor((this.orientation == 1) ? Cursor.getPredefinedCursor(11) : Cursor.getPredefinedCursor(9));
                this.revalidateSplitPane();
            }
            else if (propertyChangeEvent.getPropertyName() == "oneTouchExpandable") {
                this.oneTouchExpandableChanged();
            }
        }
    }
    
    @Override
    public void paint(Graphics g) {
        super.paint(g);
        Border border = this.getBorder();
        if (border != null) {
            Dimension size = this.getSize();
            border.paintBorder(this, g, 0, 0, size.width, size.height);
        }
    }
    
    protected void oneTouchExpandableChanged() {
        if (!DefaultLookup.getBoolean(this.splitPane, this.splitPaneUI, "SplitPane.supportsOneTouchButtons", true)) {
            return;
        }
        if (this.splitPane.isOneTouchExpandable() && this.leftButton == null && this.rightButton == null) {
            this.leftButton = this.createLeftOneTouchButton();
            if (this.leftButton != null) {
                this.leftButton.addActionListener(new BasicSplitPaneDivider.OneTouchActionHandler(true));
            }
            this.rightButton = this.createRightOneTouchButton();
            if (this.rightButton != null) {
                this.rightButton.addActionListener(new BasicSplitPaneDivider.OneTouchActionHandler(false));
            }
            if (this.leftButton != null && this.rightButton != null) {
                this.add(this.leftButton);
                this.add(this.rightButton);
            }
        }
        this.revalidateSplitPane();
        return;
    }
    
    protected JButton createLeftOneTouchButton() {
        JButton button = new JButton() {
            @Override
            public void setBorder(Border border) {
            }
            
            @Override
            public void paint(Graphics graphics) {
                if (BasicSplitPaneDivider.this.splitPane != null) {
                    int[] array = new int[3];
                    int[] array2 = new int[3];
                    graphics.setColor(this.getBackground());
                    graphics.fillRect(0, 0, this.getWidth(), this.getHeight());
                    graphics.setColor(Color.black);
                    if (BasicSplitPaneDivider.this.orientation == 0) {
                        int min2 = Math.min(this.getHeight(), BasicSplitPaneDivider.this.oneTouchSize);
                        array[0] = min2;
                        array[1] = 0;
                        array[2] = min2 << 1;
                        array2[0] = 0;
                        array2[1] = (array2[2] = min2);
                        graphics.drawPolygon(array, array2, 3);
                    }
                    else {
                        int min = Math.min(this.getWidth(), BasicSplitPaneDivider.this.oneTouchSize);
                        array[0] = (array[2] = min);
                        array2[array[1] = 0] = 0;
                        array2[2] = (array2[1] = min) << 1;
                    }
                    graphics.fillPolygon(array, array2, 3);
                }
            }
            
            @Override
            public boolean isFocusTraversable() {
                return false;
            }
        };
        button.setMinimumSize(new Dimension(this.oneTouchSize, this.oneTouchSize));
        button.setCursor(Cursor.getPredefinedCursor(0));
        button.setFocusPainted(false);
        button.setBorderPainted(false);
        button.setRequestFocusEnabled(false);
        return button;
    }
    
    protected JButton createRightOneTouchButton() {
        JButton button = new JButton() {
            @Override
            public void setBorder(Border border) {
            }
            
            @Override
            public void paint(Graphics graphics) {
                if (BasicSplitPaneDivider.this.splitPane != null) {
                    int[] array = new int[3];
                    int[] array2 = new int[3];
                    graphics.setColor(this.getBackground());
                    graphics.fillRect(0, 0, this.getWidth(), this.getHeight());
                    if (BasicSplitPaneDivider.this.orientation == 0) {
                        int min2 = Math.min(this.getHeight(), BasicSplitPaneDivider.this.oneTouchSize);
                        array[1] = (array[0] = min2) << 1;
                        array2[array[2] = 0] = min2;
                        array2[1] = (array2[2] = 0);
                    }
                    else {
                        int min = Math.min(this.getWidth(), BasicSplitPaneDivider.this.oneTouchSize);
                        array[0] = (array[2] = 0);
                        array[1] = min;
                        array2[0] = 0;
                        array2[2] = (array2[1] = min) << 1;
                    }
                    graphics.setColor(Color.black);
                    graphics.fillPolygon(array, array2, 3);
                }
            }
            
            @Override
            public boolean isFocusTraversable() {
                return false;
            }
        };
        button.setMinimumSize(new Dimension(this.oneTouchSize, this.oneTouchSize));
        button.setCursor(Cursor.getPredefinedCursor(0));
        button.setFocusPainted(false);
        button.setBorderPainted(false);
        button.setRequestFocusEnabled(false);
        return button;
    }
    
    protected void prepareForDragging() {
        this.splitPaneUI.startDragging();
    }
    
    protected void dragDividerTo(int n) {
        this.splitPaneUI.dragDividerTo(n);
    }
    
    protected void finishDraggingTo(int n) {
        this.splitPaneUI.finishDraggingTo(n);
    }
    
    protected class MouseHandler extends MouseAdapter implements MouseMotionListener
    {
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            if ((mouseEvent.getSource() == BasicSplitPaneDivider.this || mouseEvent.getSource() == BasicSplitPaneDivider.this.splitPane) && BasicSplitPaneDivider.this.dragger == null && BasicSplitPaneDivider.this.splitPane.isEnabled()) {
                Component nonContinuousLayoutDivider = BasicSplitPaneDivider.this.splitPaneUI.getNonContinuousLayoutDivider();
                if (BasicSplitPaneDivider.this.hiddenDivider != nonContinuousLayoutDivider) {
                    if (BasicSplitPaneDivider.this.hiddenDivider != null) {
                        BasicSplitPaneDivider.this.hiddenDivider.removeMouseListener(this);
                        BasicSplitPaneDivider.this.hiddenDivider.removeMouseMotionListener(this);
                    }
                    BasicSplitPaneDivider.this.hiddenDivider = nonContinuousLayoutDivider;
                    if (BasicSplitPaneDivider.this.hiddenDivider != null) {
                        BasicSplitPaneDivider.this.hiddenDivider.addMouseMotionListener(this);
                        BasicSplitPaneDivider.this.hiddenDivider.addMouseListener(this);
                    }
                }
                if (BasicSplitPaneDivider.this.splitPane.getLeftComponent() != null && BasicSplitPaneDivider.this.splitPane.getRightComponent() != null) {
                    if (BasicSplitPaneDivider.this.orientation == 1) {
                        BasicSplitPaneDivider.this.dragger = new BasicSplitPaneDivider.DragController(mouseEvent);
                    }
                    else {
                        BasicSplitPaneDivider.this.dragger = new BasicSplitPaneDivider.VerticalDragController(mouseEvent);
                    }
                    if (!BasicSplitPaneDivider.this.dragger.isValid()) {
                        BasicSplitPaneDivider.this.dragger = null;
                    }
                    else {
                        BasicSplitPaneDivider.this.prepareForDragging();
                        BasicSplitPaneDivider.this.dragger.continueDrag(mouseEvent);
                    }
                }
                mouseEvent.consume();
            }
        }
        
        @Override
        public void mouseReleased(MouseEvent mouseEvent) {
            if (BasicSplitPaneDivider.this.dragger != null) {
                if (mouseEvent.getSource() == BasicSplitPaneDivider.this.splitPane) {
                    BasicSplitPaneDivider.this.dragger.completeDrag(mouseEvent.getX(), mouseEvent.getY());
                }
                else if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                    Point location2 = BasicSplitPaneDivider.this.getLocation();
                    BasicSplitPaneDivider.this.dragger.completeDrag(mouseEvent.getX() + location2.x, mouseEvent.getY() + location2.y);
                }
                else if (mouseEvent.getSource() == BasicSplitPaneDivider.this.hiddenDivider) {
                    Point location = BasicSplitPaneDivider.this.hiddenDivider.getLocation();
                    BasicSplitPaneDivider.this.dragger.completeDrag(mouseEvent.getX() + location.x, mouseEvent.getY() + location.y);
                }
                BasicSplitPaneDivider.this.dragger = null;
                mouseEvent.consume();
            }
        }
        
        @Override
        public void mouseDragged(MouseEvent mouseEvent) {
            if (BasicSplitPaneDivider.this.dragger != null) {
                if (mouseEvent.getSource() == BasicSplitPaneDivider.this.splitPane) {
                    BasicSplitPaneDivider.this.dragger.continueDrag(mouseEvent.getX(), mouseEvent.getY());
                }
                else if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                    Point location2 = BasicSplitPaneDivider.this.getLocation();
                    BasicSplitPaneDivider.this.dragger.continueDrag(mouseEvent.getX() + location2.x, mouseEvent.getY() + location2.y);
                }
                else if (mouseEvent.getSource() == BasicSplitPaneDivider.this.hiddenDivider) {
                    Point location = BasicSplitPaneDivider.this.hiddenDivider.getLocation();
                    BasicSplitPaneDivider.this.dragger.continueDrag(mouseEvent.getX() + location.x, mouseEvent.getY() + location.y);
                }
                mouseEvent.consume();
            }
        }
        
        @Override
        public void mouseMoved(MouseEvent mouseEvent) {
        }
        
        @Override
        public void mouseEntered(MouseEvent mouseEvent) {
            if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                BasicSplitPaneDivider.this.setMouseOver(true);
            }
        }
        
        @Override
        public void mouseExited(MouseEvent mouseEvent) {
            if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                BasicSplitPaneDivider.this.setMouseOver(false);
            }
        }
    }
    
    protected class DragController
    {
        int initialX;
        int maxX;
        int minX;
        int offset;
        
        protected DragController(MouseEvent mouseEvent) {
            JSplitPane splitPane = BasicSplitPaneDivider.this.splitPaneUI.getSplitPane();
            Component leftComponent = splitPane.getLeftComponent();
            Component rightComponent = splitPane.getRightComponent();
            this.initialX = BasicSplitPaneDivider.this.getLocation().x;
            if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                this.offset = mouseEvent.getX();
            }
            else {
                this.offset = mouseEvent.getX() - this.initialX;
            }
            if (leftComponent == null || rightComponent == null || this.offset < -1 || this.offset >= BasicSplitPaneDivider.this.getSize().width) {
                this.maxX = -1;
            }
            else {
                Insets insets = splitPane.getInsets();
                if (leftComponent.isVisible()) {
                    this.minX = leftComponent.getMinimumSize().width;
                    if (insets != null) {
                        this.minX += insets.left;
                    }
                }
                else {
                    this.minX = 0;
                }
                if (rightComponent.isVisible()) {
                    this.maxX = Math.max(0, splitPane.getSize().width - (BasicSplitPaneDivider.this.getSize().width + ((insets != null) ? insets.right : 0)) - rightComponent.getMinimumSize().width);
                }
                else {
                    this.maxX = Math.max(0, splitPane.getSize().width - (BasicSplitPaneDivider.this.getSize().width + ((insets != null) ? insets.right : 0)));
                }
                if (this.maxX < this.minX) {
                    int n = 0;
                    this.maxX = n;
                    this.minX = n;
                }
            }
        }
        
        protected boolean isValid() {
            return this.maxX > 0;
        }
        
        protected int positionForMouseEvent(MouseEvent mouseEvent) {
            return Math.min(this.maxX, Math.max(this.minX, ((mouseEvent.getSource() == BasicSplitPaneDivider.this) ? (mouseEvent.getX() + BasicSplitPaneDivider.this.getLocation().x) : mouseEvent.getX()) - this.offset));
        }
        
        protected int getNeededLocation(int n, int n2) {
            return Math.min(this.maxX, Math.max(this.minX, n - this.offset));
        }
        
        protected void continueDrag(int n, int n2) {
            BasicSplitPaneDivider.this.dragDividerTo(this.getNeededLocation(n, n2));
        }
        
        protected void continueDrag(MouseEvent mouseEvent) {
            BasicSplitPaneDivider.this.dragDividerTo(this.positionForMouseEvent(mouseEvent));
        }
        
        protected void completeDrag(int n, int n2) {
            BasicSplitPaneDivider.this.finishDraggingTo(this.getNeededLocation(n, n2));
        }
        
        protected void completeDrag(MouseEvent mouseEvent) {
            BasicSplitPaneDivider.this.finishDraggingTo(this.positionForMouseEvent(mouseEvent));
        }
    }
    
    protected class VerticalDragController extends BasicSplitPaneDivider.DragController
    {
        protected VerticalDragController(MouseEvent mouseEvent) {
            super(mouseEvent);
            JSplitPane splitPane = BasicSplitPaneDivider.this.splitPaneUI.getSplitPane();
            Component leftComponent = splitPane.getLeftComponent();
            Component rightComponent = splitPane.getRightComponent();
            this.initialX = BasicSplitPaneDivider.this.getLocation().y;
            if (mouseEvent.getSource() == BasicSplitPaneDivider.this) {
                this.offset = mouseEvent.getY();
            }
            else {
                this.offset = mouseEvent.getY() - this.initialX;
            }
            if (leftComponent == null || rightComponent == null || this.offset < -1 || this.offset > BasicSplitPaneDivider.this.getSize().height) {
                this.maxX = -1;
            }
            else {
                Insets insets = splitPane.getInsets();
                if (leftComponent.isVisible()) {
                    this.minX = leftComponent.getMinimumSize().height;
                    if (insets != null) {
                        this.minX += insets.top;
                    }
                }
                else {
                    this.minX = 0;
                }
                if (rightComponent.isVisible()) {
                    this.maxX = Math.max(0, splitPane.getSize().height - (BasicSplitPaneDivider.this.getSize().height + ((insets != null) ? insets.bottom : 0)) - rightComponent.getMinimumSize().height);
                }
                else {
                    this.maxX = Math.max(0, splitPane.getSize().height - (BasicSplitPaneDivider.this.getSize().height + ((insets != null) ? insets.bottom : 0)));
                }
                if (this.maxX < this.minX) {
                    int n = 0;
                    this.maxX = n;
                    this.minX = n;
                }
            }
        }
        
        @Override
        protected int getNeededLocation(int n, int n2) {
            return Math.min(this.maxX, Math.max(this.minX, n2 - this.offset));
        }
        
        @Override
        protected int positionForMouseEvent(MouseEvent mouseEvent) {
            return Math.min(this.maxX, Math.max(this.minX, ((mouseEvent.getSource() == BasicSplitPaneDivider.this) ? (mouseEvent.getY() + BasicSplitPaneDivider.this.getLocation().y) : mouseEvent.getY()) - this.offset));
        }
    }
    
    protected class DividerLayout implements LayoutManager
    {
        @Override
        public void layoutContainer(Container container) {
            if (BasicSplitPaneDivider.this.leftButton != null && BasicSplitPaneDivider.this.rightButton != null && container == BasicSplitPaneDivider.this) {
                if (BasicSplitPaneDivider.this.splitPane.isOneTouchExpandable()) {
                    Insets insets = BasicSplitPaneDivider.this.getInsets();
                    if (BasicSplitPaneDivider.this.orientation == 0) {
                        int n3 = (insets != null) ? insets.left : 0;
                        int a2 = BasicSplitPaneDivider.this.getHeight();
                        if (insets != null) {
                            a2 = Math.max(a2 - (insets.top + insets.bottom), 0);
                        }
                        int min2 = Math.min(a2, BasicSplitPaneDivider.this.oneTouchSize);
                        int n4 = (container.getSize().height - min2) / 2;
                        if (!BasicSplitPaneDivider.this.centerOneTouchButtons) {
                            n4 = ((insets != null) ? insets.top : 0);
                            n3 = 0;
                        }
                        BasicSplitPaneDivider.this.leftButton.setBounds(n3 + BasicSplitPaneDivider.this.oneTouchOffset, n4, min2 * 2, min2);
                        BasicSplitPaneDivider.this.rightButton.setBounds(n3 + BasicSplitPaneDivider.this.oneTouchOffset + BasicSplitPaneDivider.this.oneTouchSize * 2, n4, min2 * 2, min2);
                    }
                    else {
                        int n = (insets != null) ? insets.top : 0;
                        int a = BasicSplitPaneDivider.this.getWidth();
                        if (insets != null) {
                            a = Math.max(a - (insets.left + insets.right), 0);
                        }
                        int min = Math.min(a, BasicSplitPaneDivider.this.oneTouchSize);
                        int n2 = (container.getSize().width - min) / 2;
                        if (!BasicSplitPaneDivider.this.centerOneTouchButtons) {
                            n2 = ((insets != null) ? insets.left : 0);
                            n = 0;
                        }
                        BasicSplitPaneDivider.this.leftButton.setBounds(n2, n + BasicSplitPaneDivider.this.oneTouchOffset, min, min * 2);
                        BasicSplitPaneDivider.this.rightButton.setBounds(n2, n + BasicSplitPaneDivider.this.oneTouchOffset + BasicSplitPaneDivider.this.oneTouchSize * 2, min, min * 2);
                    }
                }
                else {
                    BasicSplitPaneDivider.this.leftButton.setBounds(-5, -5, 1, 1);
                    BasicSplitPaneDivider.this.rightButton.setBounds(-5, -5, 1, 1);
                }
            }
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            if (container != BasicSplitPaneDivider.this || BasicSplitPaneDivider.this.splitPane == null) {
                return new Dimension(0, 0);
            }
            Dimension minimumSize = null;
            if (BasicSplitPaneDivider.this.splitPane.isOneTouchExpandable() && BasicSplitPaneDivider.this.leftButton != null) {
                minimumSize = BasicSplitPaneDivider.this.leftButton.getMinimumSize();
            }
            Insets insets = BasicSplitPaneDivider.this.getInsets();
            int n = BasicSplitPaneDivider.this.getDividerSize();
            if (BasicSplitPaneDivider.this.orientation == 0) {
                if (minimumSize != null) {
                    int height = minimumSize.height;
                    if (insets != null) {
                        height += insets.top + insets.bottom;
                    }
                    n = Math.max(n, height);
                }
                n = 1;
            }
            else {
                if (minimumSize != null) {
                    int width = minimumSize.width;
                    if (insets != null) {
                        width += insets.left + insets.right;
                    }
                    n = Math.max(n, width);
                }
                n = 1;
            }
            return new Dimension(n, n);
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            return this.minimumLayoutSize(container);
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
        }
        
        @Override
        public void addLayoutComponent(String s, Component component) {
        }
    }
    
    private class OneTouchActionHandler implements ActionListener
    {
        private boolean toMinimum;
        
        OneTouchActionHandler(boolean toMinimum) {
            this.toMinimum = toMinimum;
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            Insets insets = BasicSplitPaneDivider.this.splitPane.getInsets();
            int lastDividerLocation = BasicSplitPaneDivider.this.splitPane.getLastDividerLocation();
            int dividerLocation = BasicSplitPaneDivider.this.splitPaneUI.getDividerLocation(BasicSplitPaneDivider.this.splitPane);
            int dividerLocation2;
            if (this.toMinimum) {
                if (BasicSplitPaneDivider.this.orientation == 0) {
                    if (dividerLocation >= BasicSplitPaneDivider.this.splitPane.getHeight() - insets.bottom - BasicSplitPaneDivider.this.getHeight()) {
                        dividerLocation2 = Math.min(lastDividerLocation, BasicSplitPaneDivider.this.splitPane.getMaximumDividerLocation());
                        BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(false);
                    }
                    else {
                        dividerLocation2 = insets.top;
                        BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(true);
                    }
                }
                else if (dividerLocation >= BasicSplitPaneDivider.this.splitPane.getWidth() - insets.right - BasicSplitPaneDivider.this.getWidth()) {
                    dividerLocation2 = Math.min(lastDividerLocation, BasicSplitPaneDivider.this.splitPane.getMaximumDividerLocation());
                    BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(false);
                }
                else {
                    dividerLocation2 = insets.left;
                    BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(true);
                }
            }
            else if (BasicSplitPaneDivider.this.orientation == 0) {
                if (dividerLocation == insets.top) {
                    dividerLocation2 = Math.min(lastDividerLocation, BasicSplitPaneDivider.this.splitPane.getMaximumDividerLocation());
                    BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(false);
                }
                else {
                    dividerLocation2 = BasicSplitPaneDivider.this.splitPane.getHeight() - BasicSplitPaneDivider.this.getHeight() - insets.top;
                    BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(true);
                }
            }
            else if (dividerLocation == insets.left) {
                dividerLocation2 = Math.min(lastDividerLocation, BasicSplitPaneDivider.this.splitPane.getMaximumDividerLocation());
                BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(false);
            }
            else {
                dividerLocation2 = BasicSplitPaneDivider.this.splitPane.getWidth() - BasicSplitPaneDivider.this.getWidth() - insets.left;
                BasicSplitPaneDivider.this.splitPaneUI.setKeepHidden(true);
            }
            if (dividerLocation != dividerLocation2) {
                BasicSplitPaneDivider.this.splitPane.setDividerLocation(dividerLocation2);
                BasicSplitPaneDivider.this.splitPane.setLastDividerLocation(dividerLocation);
            }
        }
    }
}
